import struct
from ..publisher import HelloMsgPublisher

class HelloMsgParserV2:

    def parse(self, txUID, msg):
        parsed = {}

        if msg[1] == 1:
            parsed['deviceType'] = 'airsensor'
        elif msg[1] == 2:
            parsed['deviceType'] = 'reedsensor'

        parsed['hardwareRevision'] = "{}.{}.{}".format(msg[2], msg[3], msg[4])

        buildDate = struct.unpack(">H", msg[5:7])[0]
        buildDay = buildDate >> 11
        buildMonth = (buildDate & 0x780) >> 7
        buildYear = (buildDate & 0x7F) + 2020

        parsed['buildDate'] = "{}.{}.{}".format(buildDay, buildMonth, buildYear)

        radioSettings = msg[7]
        parsed['radioHighPower'] = radioSettings>>7
        parsed['radioMaxPower'] = (radioSettings & 0x7F) - 18

        parsed['firmwareRevision'] = struct.unpack(">H", msg[8:10])[0]

        wakeupIntervalEnc = msg[10]

        if wakeupIntervalEnc == 0:
            parsed['wakeupInterval'] = 0
        if wakeupIntervalEnc <= 25:
            parsed['wakeupInterval'] = 5 + wakeupIntervalEnc - 1
        elif wakeupIntervalEnc <= 31:
             parsed['wakeupInterval'] = 30 + (5 * (wakeupIntervalEnc % 26))
        elif wakeupIntervalEnc <= 55:
            parsed['wakeupInterval'] = 60 + (10 * (wakeupIntervalEnc % 32))
        elif wakeupIntervalEnc <= 111:
            parsed['wakeupInterval'] = 300 + (60 * (wakeupIntervalEnc % 56))

        return parsed

    def getPublisher(self, mqttClient):
        return HelloMsgPublisher.HelloMsgPublisher(mqttClient)
