import json, datetime
from datetime import timezone
from . import Publisher

class HelloMsgPublisher(Publisher.Publisher):

    def __init__(self, mqttClient):
        super().__init__(mqttClient)

    def publish(self, sensorId, timestamp, parsedMsg, rssi):
        if not 'deviceType' in parsedMsg:
            return

        if parsedMsg['deviceType'] == 'reedsensor':
            sensorMqttCat = 'sensors/reed'
        elif parsedMsg['deviceType'] == 'airsensor':
            sensorMqttCat = 'sensors/air'
        else:
            return

        if 'wakeupInterval' in parsedMsg:
            self.mqttClient.publish('{}/{}/wakeup_interval'.format(sensorMqttCat, sensorId), parsedMsg['wakeupInterval'], qos=1, retain=True)

        if 'firmwareRevision' in parsedMsg:
            self.mqttClient.publish('{}/{}/firmware/revision'.format(sensorMqttCat, sensorId), parsedMsg['firmwareRevision'], qos=1, retain=True)

        if 'hardwareRevision' in parsedMsg:
            self.mqttClient.publish('{}/{}/hardware/revision'.format(sensorMqttCat, sensorId), parsedMsg['hardwareRevision'], qos=1, retain=True)

        if 'buildDate' in parsedMsg:
            #assumes local time
            dt = datetime.datetime.strptime(parsedMsg['buildDate'], "%d.%m.%Y")
            dt = int(dt.replace(tzinfo=timezone.utc).timestamp())
            self.mqttClient.publish('{}/{}/hardware/build_date'.format(sensorMqttCat, sensorId), dt, qos=1, retain=True)

        if 'radioHighPower' in parsedMsg and 'radioMaxPower' in parsedMsg:
            jsonObj = {'isHP': int(parsedMsg['radioHighPower']), 'maxPower': int(parsedMsg['radioMaxPower'])}
            jsonStr = json.dumps(jsonObj)

            self.mqttClient.publish('{}/{}/hardware/radio'.format(sensorMqttCat, sensorId), jsonStr, qos=1, retain=True, content_type='cnq/0.1+json')
